@@ -840,10 +840,10 @@ panel_ditem_editor_changed (PanelDItemEditor *dialog)
 static void
 panel_ditem_editor_activated (PanelDItemEditor *dialog)
 {
-	if (GTK_WIDGET_VISIBLE (dialog->priv->ok_button))
+	if (gtk_widget_get_visible (dialog->priv->ok_button))
 		gtk_dialog_response (GTK_DIALOG (dialog),
 				     GTK_RESPONSE_OK);
-	else if (GTK_WIDGET_VISIBLE (dialog->priv->close_button))
+	else if (gtk_widget_get_visible (dialog->priv->close_button))
 		gtk_dialog_response (GTK_DIALOG (dialog),
 				     GTK_RESPONSE_CLOSE);
 }
